@@ -504,7 +504,7 @@ class ModelFolder(_Folder):
                 apt_group_folder, self._config['APERTURE-GROUP']['states'])
         return parse_states(states_file)
 
-    def combined_receivers(self, folder='receivers'):
+    def combined_receivers(self, folder='receivers', auto_mtx_path=True):
         """Write combined receiver files to folder.
 
         This function writes a combined receiver file of the aperture groups for all
@@ -517,16 +517,21 @@ class ModelFolder(_Folder):
 
         Arg:
             folder: A path of the target folder to write files to (default: 'receivers').
+            auto_mtx_path: If set to True, then the path of the view matrices will be
+                specified automatically.
+        Returns:
+            A dictionary containing grid identifiers as keys and the receiver rad files
+            as values.
         """
         grids = self.grid_data_all()
         apt_group_folder = self.aperture_group_folder(full=False)
 
-        states = self.aperture_groups_states()
+        states = self.aperture_groups_states(full=True)
 
         if not os.path.isdir(folder):
             os.mkdir(folder)
 
-        receiver_list = []
+        receiver_dict = dict()
 
         # find the light_path for each grid
         for grid in grids.values():
@@ -541,12 +546,11 @@ class ModelFolder(_Folder):
                 grid['identifier'],
                 apt_group_folder,
                 aperture_groups,
-                folder
-            )
+                folder, add_output_header=auto_mtx_path)
 
-            receiver_list.append(receiver_file)
+            receiver_dict[grid['identifier']] = receiver_file
 
-        return receiver_list
+        return receiver_dict
 
     def dynamic_scene(self, indoor=False, reload=False):
         """List of dynamic non-aperture geometries.
